@@ -19,7 +19,6 @@
 #include "Charmonizer/Core/HeaderChecker.h"
 #include "Charmonizer/Core/Compiler.h"
 #include "Charmonizer/Core/ConfWriter.h"
-#include "Charmonizer/Core/Stat.h"
 #include "Charmonizer/Core/Util.h"
 #include "Charmonizer/Probe/LargeFiles.h"
 #include <errno.h>
@@ -27,22 +26,30 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+static const char* off64_options[] = {
+    "off64_t",
+    "off_t",
+    "__int64",
+    "long"
+};
+
+#define NUM_OFF64_OPTIONS (sizeof(off64_options) / sizeof(off64_options[0]))
+
 /* Sets of symbols which might provide large file support. */
-typedef struct off64_combo {
+typedef struct stdio64_combo {
     const char *includes;
     const char *fopen_command;
     const char *ftell_command;
     const char *fseek_command;
-    const char *offset64_type;
-} off64_combo;
-static off64_combo off64_combos[] = {
-    { "#include <sys/types.h>\n", "fopen64",   "ftello64",  "fseeko64",  "off64_t" },
-    { "#include <sys/types.h>\n", "fopen",     "ftello64",  "fseeko64",  "off64_t" },
-    { "#include <sys/types.h>\n", "fopen",     "ftello",    "fseeko",    "off_t"   },
-    { "",                         "fopen",     "ftell",     "fseek",     "off_t"   },
-    { "",                         "fopen",     "_ftelli64", "_fseeki64", "__int64" },
-    { "",                         "fopen",     "ftell",     "fseek",     "long"    },
-    { NULL, NULL, NULL, NULL, NULL }
+} stdio64_combo;
+static stdio64_combo stdio64_combos[] = {
+    { "#include <sys/types.h>\n", "fopen64",   "ftello64",  "fseeko64"  },
+    { "#include <sys/types.h>\n", "fopen",     "ftello64",  "fseeko64"  },
+    { "#include <sys/types.h>\n", "fopen",     "ftello",    "fseeko"    },
+    { "",                         "fopen",     "ftell",     "fseek"     },
+    { "",                         "fopen",     "_ftelli64", "_fseeki64" },
+    { "",                         "fopen",     "ftell",     "fseek"     },
+    { NULL, NULL, NULL, NULL }
 };
 
 typedef struct unbuff_combo {
@@ -57,10 +64,15 @@ static unbuff_combo unbuff_combos[] = {
     { NULL, NULL, NULL }
 };
 
+/* Check for a 64-bit file pointer type.
+ */
+static const chaz_bool_t
+S_probe_off64(void);
+
 /* Check what name 64-bit ftell, fseek go by.
  */
 static chaz_bool_t
-S_probe_off64(off64_combo *combo);
+S_probe_stdio64(stdio64_combo *combo);
 
 /* Check for a 64-bit lseek.
  */
@@ -72,22 +84,6 @@ S_probe_lseek(unbuff_combo *combo);
 static chaz_bool_t
 S_probe_pread64(unbuff_combo *combo);
 
-/* Determine whether we can use sparse files.
- */
-static chaz_bool_t
-S_check_sparse_files(void);
-
-/* Helper for check_sparse_files().
- */
-static void
-S_test_sparse_file(long offset, Stat *st);
-
-/* See if trying to write a 5 GB file in a subprocess bombs out.  If it
- * doesn't, then the test suite can safely verify large file support.
- */
-static chaz_bool_t
-S_can_create_big_files(void);
-
 /* Vars for holding lfs commands, once they're discovered. */
 static char fopen_command[10];
 static char fseek_command[10];
@@ -98,44 +94,45 @@ static char off64_type[10];
 
 void
 LargeFiles_run(void) {
-    chaz_bool_t success = false;
+    chaz_bool_t found_off64_t = false;
+    chaz_bool_t found_stdio64 = false;
     chaz_bool_t found_lseek = false;
     chaz_bool_t found_pread64 = false;
     unsigned i;
+    const char *stat_includes = "#include <stdio.h>\n#include <sys/stat.h>";
 
     ConfWriter_start_module("LargeFiles");
 
-    /* See if off64_t and friends exist or have synonyms. */
-    for (i = 0; off64_combos[i].includes != NULL; i++) {
-        off64_combo combo = off64_combos[i];
-        success = S_probe_off64(&combo);
-        if (success) {
+    /* Find off64_t or equivalent. */
+    found_off64_t = S_probe_off64();
+    if (found_off64_t) {
+        ConfWriter_append_conf("#define CHY_HAS_64BIT_OFFSET_TYPE\n");
+        ConfWriter_append_conf("#define chy_off64_t %s\n",  off64_type);
+    }
+
+    /* See if stdio variants with 64-bit support exist. */
+    for (i = 0; stdio64_combos[i].includes != NULL; i++) {
+        stdio64_combo combo = stdio64_combos[i];
+        if (S_probe_stdio64(&combo)) {
+            found_stdio64 = true;
+            ConfWriter_append_conf("#define CHY_HAS_64BIT_STDIO\n");
             strcpy(fopen_command, combo.fopen_command);
             strcpy(fseek_command, combo.fseek_command);
             strcpy(ftell_command, combo.ftell_command);
-            strcpy(off64_type, combo.offset64_type);
+            ConfWriter_append_conf("#define chy_fopen64 %s\n",  fopen_command);
+            ConfWriter_append_conf("#define chy_ftello64 %s\n", ftell_command);
+            ConfWriter_append_conf("#define chy_fseeko64 %s\n", fseek_command);
             break;
         }
     }
 
-    /* Write the affirmations/definitions. */
-    if (success) {
-        ConfWriter_append_conf("#define CHY_HAS_LARGE_FILE_SUPPORT\n");
-        /* Alias these only if they're not already provided and correct. */
-        if (strcmp(off64_type, "off64_t") != 0) {
-            ConfWriter_append_conf("#define chy_off64_t %s\n",  off64_type);
-            ConfWriter_append_conf("#define chy_fopen64 %s\n",  fopen_command);
-            ConfWriter_append_conf("#define chy_ftello64 %s\n", ftell_command);
-            ConfWriter_append_conf("#define chy_fseeko64 %s\n", fseek_command);
-        }
-    }
-
     /* Probe for 64-bit versions of lseek and pread (if we have an off64_t). */
-    if (success) {
+    if (found_off64_t) {
         for (i = 0; unbuff_combos[i].lseek_command != NULL; i++) {
             unbuff_combo combo = unbuff_combos[i];
             found_lseek = S_probe_lseek(&combo);
             if (found_lseek) {
+                ConfWriter_append_conf("#define CHY_HAS_64BIT_LSEEK\n");
                 strcpy(lseek_command, combo.lseek_command);
                 ConfWriter_append_conf("#define chy_lseek64 %s\n",
                                        lseek_command);
@@ -146,6 +143,7 @@ LargeFiles_run(void) {
             unbuff_combo combo = unbuff_combos[i];
             found_pread64 = S_probe_pread64(&combo);
             if (found_pread64) {
+                ConfWriter_append_conf("#define CHY_HAS_64BIT_PREAD\n");
                 strcpy(pread64_command, combo.pread64_command);
                 ConfWriter_append_conf("#define chy_pread64 %s\n",
                                        pread64_command);
@@ -155,51 +153,112 @@ LargeFiles_run(void) {
         }
     }
 
-    /* Check for sparse files. */
-    if (S_check_sparse_files()) {
-        ConfWriter_append_conf("#define CHAZ_HAS_SPARSE_FILES\n");
-        /* See if we can create a 5 GB file without crashing. */
-        if (success && S_can_create_big_files()) {
-            ConfWriter_append_conf("#define CHAZ_CAN_CREATE_BIG_FILES\n");
-        }
+    /* Make checks needed for testing. */
+    if (HeadCheck_check_header("sys/stat.h")) {
+        ConfWriter_append_conf("#define CHAZ_HAS_SYS_STAT_H\n");
     }
-    else {
-        ConfWriter_append_conf("#define CHAZ_NO_SPARSE_FILES\n");
+    if (HeadCheck_check_header("io.h")) {
+        ConfWriter_append_conf("#define CHAZ_HAS_IO_H\n");
+    }
+    if (HeadCheck_check_header("fcntl.h")) {
+        ConfWriter_append_conf("#define CHAZ_HAS_FCNTL_H\n");
+    }
+    if (HeadCheck_contains_member("struct stat", "st_size", stat_includes)) {
+        ConfWriter_append_conf("#define CHAZ_HAS_STAT_ST_SIZE\n");
+    }
+    if (HeadCheck_contains_member("struct stat", "st_blocks", stat_includes)) {
+        ConfWriter_append_conf("#define CHAZ_HAS_STAT_ST_BLOCKS\n");
     }
 
     /* Short names. */
-    if (success) {
-        ConfWriter_start_short_names();
-        ConfWriter_shorten_macro("HAS_LARGE_FILE_SUPPORT");
-
-        /* Alias these only if they're not already provided and correct. */
+    ConfWriter_start_short_names();
+    if (found_off64_t) {
+        ConfWriter_shorten_macro("HAS_64BIT_OFFSET_TYPE");
         if (strcmp(off64_type, "off64_t") != 0) {
             ConfWriter_shorten_typedef("off64_t");
+        }
+    }
+    if (found_stdio64) {
+        ConfWriter_shorten_macro("HAS_64BIT_STDIO");
+        if (strcmp(fopen_command, "fopen64") != 0) {
             ConfWriter_shorten_function("fopen64");
+        }
+        if (strcmp(fopen_command, "ftello64") != 0) {
             ConfWriter_shorten_function("ftello64");
+        }
+        if (strcmp(fopen_command, "fseeko64") != 0) {
             ConfWriter_shorten_function("fseeko64");
         }
-        if (found_lseek && strcmp(lseek_command, "lseek64") != 0) {
+    }
+    if (found_lseek) {
+        ConfWriter_shorten_macro("HAS_64BIT_LSEEK");
+        if (strcmp(lseek_command, "lseek64") != 0) {
             ConfWriter_shorten_function("lseek64");
         }
-        if (found_pread64 && strcmp(pread64_command, "pread64") != 0) {
+    }
+    if (found_pread64) {
+        ConfWriter_shorten_macro("HAS_64BIT_PREAD");
+        if (strcmp(pread64_command, "pread64") != 0) {
             ConfWriter_shorten_function("pread64");
         }
-        ConfWriter_end_short_names();
     }
+    ConfWriter_end_short_names();
 
     ConfWriter_end_module();
 }
 
-/* Code for checking ftello64 and friends. */
+/* Code for finding an off64_t or some other 64-bit signed type. */
 static const char off64_code[] =
+    QUOTE(  %s                                        )
+    QUOTE(  #include "_charm.h"                       )
+    QUOTE(  int main()                                )
+    QUOTE(  {                                         )
+    QUOTE(      Charm_Setup;                          )
+    QUOTE(      printf("%%d", (int)sizeof(%s));       )
+    QUOTE(      return 0;                             )
+    QUOTE(  }                                         );
+
+static const chaz_bool_t
+S_probe_off64(void) {
+    size_t needed = sizeof(off64_code) + 100;
+    char *code_buf = (char*)malloc(needed);
+    int i;
+    chaz_bool_t success = false;
+    for (i = 0; i < NUM_OFF64_OPTIONS; i++) {
+        const char *candidate = off64_options[i];
+        char *output;
+        size_t output_len;
+        chaz_bool_t has_sys_types_h = HeadCheck_check_header("sys/types.h");
+        const char *sys_types_include = has_sys_types_h
+                                        ? "#include <sys/types.h>"
+                                        : "";
+
+        /* Execute the probe. */
+        sprintf(code_buf, off64_code, sys_types_include, candidate);
+        output = CC_capture_output(code_buf, strlen(code_buf), &output_len);
+        if (output != NULL) {
+            long sizeof_candidate = strtol(output, NULL, 10);
+            free(output);
+            if (sizeof_candidate == 8) {
+                strcpy(off64_type, candidate);
+                success = true;
+                break;
+            }
+        }
+    }
+    free(code_buf);
+    return success;
+}
+
+/* Code for checking ftello64 and friends. */
+static const char stdio64_code[] =
     QUOTE(  %s                                         )
     QUOTE(  #include "_charm.h"                        )
     QUOTE(  int main() {                               )
     QUOTE(      %s pos;                                )
     QUOTE(      FILE *f;                               )
     QUOTE(      Charm_Setup;                           )
-    QUOTE(      f = %s("_charm_off64", "w");           )
+    QUOTE(      f = %s("_charm_stdio64", "w");         )
     QUOTE(      if (f == NULL) return -1;              )
     QUOTE(      printf("%%d", (int)sizeof(%s));        )
     QUOTE(      pos = %s(stdout);                      )
@@ -209,11 +268,11 @@ static const char off64_code[] =
 
 
 static chaz_bool_t
-S_probe_off64(off64_combo *combo) {
+S_probe_stdio64(stdio64_combo *combo) {
     char *output = NULL;
     size_t output_len;
-    size_t needed = sizeof(off64_code)
-                    + (2 * strlen(combo->offset64_type))
+    size_t needed = sizeof(stdio64_code)
+                    + (2 * strlen(off64_type))
                     + strlen(combo->fopen_command)
                     + strlen(combo->ftell_command)
                     + strlen(combo->fseek_command)
@@ -222,8 +281,8 @@ S_probe_off64(off64_combo *combo) {
     chaz_bool_t success = false;
 
     /* Prepare the source code. */
-    sprintf(code_buf, off64_code, combo->includes, combo->offset64_type,
-            combo->fopen_command, combo->offset64_type, combo->ftell_command,
+    sprintf(code_buf, stdio64_code, combo->includes, off64_type,
+            combo->fopen_command, off64_type, combo->ftell_command,
             combo->fseek_command);
 
     /* Verify compilation and that the offset type has 8 bytes. */
@@ -236,8 +295,8 @@ S_probe_off64(off64_combo *combo) {
         free(output);
     }
 
-    if (!Util_remove_and_verify("_charm_off64")) {
-        Util_die("Failed to remove '_charm_off64'");
+    if (!Util_remove_and_verify("_charm_stdio64")) {
+        Util_die("Failed to remove '_charm_stdio64'");
     }
 
     return success;
@@ -322,110 +381,3 @@ S_probe_pread64(unbuff_combo *combo) {
     return success;
 }
 
-static chaz_bool_t
-S_check_sparse_files(void) {
-    Stat st_a, st_b;
-
-    /* Bail out if we can't stat() a file. */
-    if (!HeadCheck_check_header("sys/stat.h")) {
-        return false;
-    }
-
-    /* Write and stat a 1 MB file and a 2 MB file, both of them sparse. */
-    S_test_sparse_file(1000000, &st_a);
-    S_test_sparse_file(2000000, &st_b);
-    if (!(st_a.valid && st_b.valid)) {
-        return false;
-    }
-    if (st_a.size != 1000001) {
-        Util_die("Expected size of 1000001 but got %ld", (long)st_a.size);
-    }
-    if (st_b.size != 2000001) {
-        Util_die("Expected size of 2000001 but got %ld", (long)st_b.size);
-    }
-
-    /* See if two files with very different lengths have the same block size. */
-    if (st_a.blocks == st_b.blocks) {
-        return true;
-    }
-    else {
-        return false;
-    }
-}
-
-static void
-S_test_sparse_file(long offset, Stat *st) {
-    FILE *sparse_fh;
-
-    /* Make sure the file's not there, then open. */
-    Util_remove_and_verify("_charm_sparse");
-    if ((sparse_fh = fopen("_charm_sparse", "w+")) == NULL) {
-        Util_die("Couldn't open file '_charm_sparse'");
-    }
-
-    /* Seek fh to [offset], write a byte, close file. */
-    if ((fseek(sparse_fh, offset, SEEK_SET)) == -1) {
-        Util_die("seek failed: %s", strerror(errno));
-    }
-    if ((fprintf(sparse_fh, "X")) != 1) {
-        Util_die("fprintf failed");
-    }
-    if (fclose(sparse_fh)) {
-        Util_die("Error closing file '_charm_sparse': %s", strerror(errno));
-    }
-
-    /* Stat the file. */
-    Stat_stat("_charm_sparse", st);
-
-    remove("_charm_sparse");
-}
-
-/* Open a file, seek to a loc, print a char, and communicate success. */
-static const char create_bigfile_code[] =
-    QUOTE(  #include "_charm.h"                                      )
-    QUOTE(  int main() {                                             )
-    QUOTE(      FILE *fh = fopen("_charm_large_file_test", "w+");    )
-    QUOTE(      int check_seek;                                      )
-    QUOTE(      Charm_Setup;                                         )
-    /* Bail unless seek succeeds. */
-    QUOTE(      check_seek = %s(fh, 5000000000, SEEK_SET);           )
-    QUOTE(      if (check_seek == -1)                                )
-    QUOTE(          exit(1);                                         )
-    /* Bail unless we write successfully. */
-    QUOTE(      if (fprintf(fh, "X") != 1)                           )
-    QUOTE(          exit(1);                                         )
-    QUOTE(      if (fclose(fh))                                      )
-    QUOTE(          exit(1);                                         )
-    /* Communicate success to Charmonizer. */
-    QUOTE(      printf("1");                                         )
-    QUOTE(      return 0;                                            )
-    QUOTE(  }                                                        );
-
-static chaz_bool_t
-S_can_create_big_files(void) {
-    char *output;
-    size_t output_len;
-    FILE *truncating_fh;
-    size_t needed = strlen(create_bigfile_code)
-                    + strlen(fseek_command)
-                    + 10;
-    char *code_buf = (char*)malloc(needed);
-
-    /* Concat the source strings, compile the file, capture output. */
-    sprintf(code_buf, create_bigfile_code, fseek_command);
-    output = CC_capture_output(code_buf, strlen(code_buf), &output_len);
-
-    /* Truncate, just in case the call to remove fails. */
-    truncating_fh = fopen("_charm_large_file_test", "w");
-    if (truncating_fh != NULL) {
-        fclose(truncating_fh);
-    }
-    Util_remove_and_verify("_charm_large_file_test");
-
-    /* Return true if the test app made it to the finish line. */
-    free(code_buf);
-    return output == NULL ? false : true;
-}
-
-
-
