@@ -23,8 +23,10 @@
 #include "CFCFunction.h"
 #include "CFCHierarchy.h"
 #include "CFCMethod.h"
+#include "CFCMemPool.h"
 #include "CFCParamList.h"
 #include "CFCParcel.h"
+#include "CFCParser.h"
 #include "CFCSymbol.h"
 #include "CFCType.h"
 #include "CFCUtil.h"
