@@ -148,7 +148,7 @@ Hash_load(Hash *self, Obj *dump) {
                       VTable_Get_Name(vtable));
             }
             else if (load != (Obj_load_t)Hash_load) { // stop inf loop
-                return load(NULL, dump);
+                return VTable_Load_Obj(vtable, dump);
             }
         }
     }
