@@ -113,19 +113,16 @@ IxSearcher_top_docs(IndexSearcher *self, Query *query, uint32_t num_wanted,
     uint32_t       wanted    = num_wanted > doc_max ? doc_max : num_wanted;
     SortCollector *collector = SortColl_new(schema, sort_spec, wanted);
     IxSearcher_Collect(self, query, (Collector*)collector);
-    {
-        VArray  *match_docs = SortColl_Pop_Match_Docs(collector);
-        int32_t  total_hits = SortColl_Get_Total_Hits(collector);
-        TopDocs *retval     = TopDocs_new(match_docs, total_hits);
-        DECREF(collector);
-        DECREF(match_docs);
-        return retval;
-    }
+    VArray  *match_docs = SortColl_Pop_Match_Docs(collector);
+    int32_t  total_hits = SortColl_Get_Total_Hits(collector);
+    TopDocs *retval     = TopDocs_new(match_docs, total_hits);
+    DECREF(collector);
+    DECREF(match_docs);
+    return retval;
 }
 
 void
 IxSearcher_collect(IndexSearcher *self, Query *query, Collector *collector) {
-    uint32_t i, max;
     VArray   *const seg_readers = self->seg_readers;
     I32Array *const seg_starts  = self->seg_starts;
     bool_t    need_score        = Coll_Need_Score(collector);
@@ -135,7 +132,7 @@ IxSearcher_collect(IndexSearcher *self, Query *query, Collector *collector) {
                                                Query_Get_Boost(query), false);
 
     // Accumulate hits into the Collector.
-    for (i = 0, max = VA_Get_Size(seg_readers); i < max; i++) {
+    for (uint32_t i = 0, max = VA_Get_Size(seg_readers); i < max; i++) {
         SegReader *seg_reader = (SegReader*)VA_Fetch(seg_readers, i);
         DeletionsReader *del_reader = (DeletionsReader*)SegReader_Fetch(
                                           seg_reader,
