@@ -79,7 +79,7 @@ FSDH_do_open(FSDirHandle *self, const CharBuf *dir) {
         // Deal with Windows ceiling on file path lengths.
         Err_set_error(Err_new(CB_newf("Directory path is too long: %o",
                                       dir)));
-        LUCY_DECREF(self);
+        CFISH_DECREF(self);
         return NULL;
     }
 
@@ -93,7 +93,7 @@ FSDH_do_open(FSDirHandle *self, const CharBuf *dir) {
     if (INVALID_HANDLE_VALUE == self->sys_dirhandle) {
         // Directory inaccessible or doesn't exist.
         Err_set_error(Err_new(CB_newf("Failed to open dir '%o'", dir)));
-        LUCY_DECREF(self);
+        CFISH_DECREF(self);
         return NULL;
     }
     else {
@@ -150,7 +150,7 @@ FSDH_close(FSDirHandle *self) {
 
     // If we encountered an error condition previously, report it now.
     if (self->saved_error) {
-        Err_set_error((Err*)LUCY_INCREF(self->saved_error));
+        Err_set_error((Err*)CFISH_INCREF(self->saved_error));
         return false;
     }
     else {
@@ -184,15 +184,13 @@ FSDH_next(FSDirHandle *self) {
     }
 
     // Process the results of the iteration.
-    {
-        size_t len = strlen(find_data->cFileName);
-        if (SI_is_updir(find_data->cFileName, len)) {
-            return FSDH_Next(self);
-        }
-        else {
-            CB_Mimic_Str(self->entry, find_data->cFileName, len);
-            return true;
-        }
+    size_t len = strlen(find_data->cFileName);
+    if (SI_is_updir(find_data->cFileName, len)) {
+        return FSDH_Next(self);
+    }
+    else {
+        CB_Mimic_Str(self->entry, find_data->cFileName, len);
+        return true;
     }
 }
 
